<?php
/**
 * OOPでBBS (Step6)
 *
 * オブジェクト指向プログラミングで掲示板を作ってみる。
 * ブログでその作り方を晒すために書いたものです。
 * 詳しい事は当該記事を見てください。 
 *
 *
 *           
 * PHP version 5.3
 *
 * LICENSE : このソースはCreative Commons 表示 - 非営利 2.1 日本 Licenseです。
 *           改変は自由ですが営利目的で利用することは出来ません。
 * 
 * @category  Step6
 * @package   OOP-BBS
 * @author    Tenderfeel <tenderfeel@gmail.com>
 * @copyright Copyright (c) 2010 Tenderfeel.(http://webtecnote.com)
 * @license   http://creativecommons.org/licenses/by-nc/2.1/jp/
 * @since     File available since Release 1.0.0 (step5)
 *
 */
 
 
/**
 * 掲示板の設定クラス
 *
 * bbs.iniから設定内容を読み込んで
 * iniプロパティに連想配列形式で設定を保持します
 *
 * <step6>
 * とくに変更なし
 * 
 * @author    Tenderfeel <tenderfeel@gmail.com>
 * @copyright Copyright (c) 2010 Tenderfeel.(http://webtecnote.com)
 * @license   Creative Commons BY-NC http://creativecommons.org/licenses/by-nc/2.1/jp/
 * @since     File available since Release 1.5.0 (step5)
 */

class Config {
    
    private $ini;
    
    public function __construct($iniFilePath)
    {
        if (true == file_exists($iniFilePath)) {
            $this->ini = parse_ini_file($iniFilePath, true);
        }
    }
    
    /**
     * 設定のゲッター
     * @param {string} $name 設定のキー
     * @return {string} iniファイルに書かれた文字列
     * @since 1.5 (step5)
     */
    public function get($name)
    {
        if(array_key_exists($name, $this->ini) === true)
            return $this->ini[$name];
        else
            return false;
    }
    
    /**
     * フォーム設定のゲッター
     * @return {array} nameキーの配列
     * @since 1.5 (step5)
     */
    public function getInputs()
    {
        return explode(',', $this->ini['bbs_inputs']);
    }
}
?>